'use client'

import Link from 'next/link'
import { useState, useEffect } from 'react'
import { motion } from 'framer-motion'
import AboveHeaderTicker from '@/components/ui/header-ticker';

export default function Header() {
  const [scrollY, setScrollY] = useState(0)

  useEffect(() => {
    const handleScroll = () => setScrollY(window.scrollY)
    window.addEventListener('scroll', handleScroll)
    return () => window.removeEventListener('scroll', handleScroll)
  }, [])

  return (
    <header>
      <AboveHeaderTicker />

      <nav className="container mx-auto px-4 py-4 flex justify-between items-center">
        <div className="text-2xl font-bold">
          <Link href="/">
            <motion.span
              className="text-blue-600 hover:text-blue-800 transition-colors"
              whileHover={{ scale: 1.05 }}
              whileTap={{ scale: 0.95 }}
            >
              Logo
            </motion.span>
          </Link>
        </div>
        <ul className="flex space-x-6">
          <li>
            <Link href="/">
              <motion.span className="hover:text-blue-600 transition-colors" whileHover={{ y: -2 }} whileTap={{ y: 0 }}>Home</motion.span>
            </Link>
          </li>
          <li>
            <Link href="/#features">
              <motion.span className="hover:text-blue-600 transition-colors" whileHover={{ y: -2 }} whileTap={{ y: 0 }}>Features</motion.span>
            </Link>
          </li>
          <li>
            <Link href="/about">
              <motion.span className="hover:text-blue-600 transition-colors" whileHover={{ y: -2 }} whileTap={{ y: 0 }}>About</motion.span>
            </Link>
          </li>
          <li>
            <Link href="/#contact">
              <motion.span className="hover:text-blue-600 transition-colors" whileHover={{ y: -2 }} whileTap={{ y: 0 }}>Contact</motion.span>
            </Link>
          </li>
        </ul>
      </nav>
    </header>
  )
}
